﻿using Hotline.Application.ExportWord;
using Hotline.Orders;
using Hotline.Share.Dtos.OrderExportWord;
using MapsterMapper;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using System.Diagnostics;
using XF.Domain.Repository;

namespace Hotline.Api.Controllers
{
    public class ExportWordController : BaseController
    {
        private readonly IOrderRepository _orderRepository;
        private readonly IWordHelperService _wordHelperService;
        private readonly IMapper _mapper;
        private readonly IRepository<OrderVisit> _orderVisitRepository;
        private readonly IRepository<OrderVisitDetail> _orderVisitedDetailRepository;
        private readonly ILogger<ExportWordController> _logger;

        public ExportWordController(IOrderRepository orderRepository,
            IWordHelperService wordHelperService,
            IMapper mapper,
           IRepository<OrderVisit> orderVisitRepository,
           IRepository<OrderVisitDetail> orderVisitedDetailRepository,
           ILogger<ExportWordController> logger)
        {
            _orderRepository = orderRepository;
            _wordHelperService = wordHelperService;
            _mapper = mapper;
            _orderVisitRepository = orderVisitRepository;
            _orderVisitedDetailRepository = orderVisitedDetailRepository;
            _logger = logger;
        }

        [AllowAnonymous]
        [HttpGet("gettest")]
        public void GetTest()
        {
            var path = $"{Directory.GetCurrentDirectory()}/templateword/测试.doc";

            var sss = Directory.Exists(Path.Combine(Directory.GetCurrentDirectory(), "templateword"));
            if (sss ) 
            _logger.LogInformation("检测成功");
            else
                _logger.LogInformation("检测失败");

            string[] files = Directory.GetFiles($"{Directory.GetCurrentDirectory()}/templateword");

            foreach (string file in files)
            {
                _logger.LogInformation("文件"+file);
            }
        }


        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [HttpPost("order_submission_form")]
        [AllowAnonymous]
        public async Task<IActionResult> OrderSubmissionForm([FromBody] List<string> Ids)
        {
            var streams = new Dictionary<string, Stream>();
            var path = $"{Directory.GetCurrentDirectory()}/templateword/yibinjiaobandan.doc";
            //var path = $"{Environment.CurrentDirectory}/Template/yibinjiaobandan.doc";

            foreach (var item in Ids)
            {
                var order = await _orderRepository.GetAsync(item, HttpContext.RequestAborted);
                if (order == null)
                    continue;

                var exportTest = _mapper.Map<OrderSubmissionForm>(order);

                //查询回访信息
                var visitData = await _orderVisitRepository.GetAsync(p => p.OrderId == order.Id, HttpContext.RequestAborted);
                if (visitData != null)
                {
                    //回访明细
                    var visitDetail = await _orderVisitedDetailRepository.Queryable().Where(p => p.VisitId == visitData.Id && p.VisitTarget == Share.Enums.Order.EVisitTarget.Org).ToListAsync();
                    string visit = "";
                    foreach (var itemVisit in visitDetail)
                    {
                        visit += "回访部门：" + itemVisit.VisitOrgName;
                        visit += " \n办件结果：" + itemVisit.OrgProcessingResults?.Value + "    办事态度：" + itemVisit.OrgHandledAttitude?.Value + "\n";

                        if (itemVisit.VisitOrgCode == order.ActualHandleOrgCode)
                            exportTest.VisitContent = "回访内容：" + itemVisit.VisitContent;
                    }
                    exportTest.VisitOrg = visit;
                }
                streams.Add(order.No + path.Substring(path.LastIndexOf(".")), _wordHelperService.WordStream(path, exportTest));
            }

            //调用压缩方法 进行压缩 (接收byte[] 数据)
            byte[] fileBytes = _wordHelperService.ConvertZipStream(streams);
            HttpContext.Response.Headers.Add("Access-Control-Expose-Headers", "Content-Disposition");
            var name = DateTime.Now.ToString("yyyyMMddHHmmss");
            return File(fileBytes, "application/octet-stream", $"{name}.zip");
        }

    }
}
